@@ -53,6 +53,7 @@ var ConnectionRow = new Lang.Class({
 
         let insensitiveDesc = new Gtk.Label({ label: _("Already added"),
                                               hexpand: true,
+                                              no_show_all: true,
                                               halign: Gtk.Align.END });
         box.add(insensitiveDesc);
 
@@ -71,10 +72,20 @@ var ConnectionRow = new Lang.Class({
 var ConnectionsList = new Lang.Class({
     Name: 'ConnectionsList',
     Extends: Gtk.ScrolledWindow,
+    Properties: {
+        'favorites-only': GObject.ParamSpec.boolean('favorites-only',
+                                                    'favorites-only',
+                                                    'favorites-only',
+                                                    GObject.ParamFlags.READWRITE |
+                                                    GObject.ParamFlags.CONSTRUCT_ONLY,
+                                                    false)
+    },
     Signals: { 'account-created': { param_types: [Tp.Account.$gtype] },
                'account-selected': {}},
 
     _init: function(params) {
+        this._favoritesOnly = false;
+
         this.parent(params);
 
         this.hscrollbar_policy = Gtk.PolicyType.NEVER;
@@ -105,6 +116,18 @@ var ConnectionsList = new Lang.Class({
         this._networksChanged();
     },
 
+    get favorites_only() {
+        return this._favoritesOnly;
+    },
+
+    set favorites_only(favsOnly) {
+        if (this._favoritesOnly == favsOnly)
+            return;
+
+        this._favoritesOnly = favsOnly;
+        this.notify('favorites-only');
+    },
+
     setFilter: function(filter) {
         if (Utils.updateTerms(this._filterTerms, filter))
             this._list.invalidate_filter();
@@ -116,6 +139,12 @@ var ConnectionsList = new Lang.Class({
             row.activate();
     },
 
+    activateSelected: function() {
+        let row = this._list.get_selected_row();
+        if (row)
+            row.activate();
+    },
+
     _filterRows: function(row) {
         let matchTerms = this._networksManager.getNetworkMatchTerms(row.id);
         return this._filterTerms.every(term => {
@@ -139,6 +168,10 @@ var ConnectionsList = new Lang.Class({
         }).map(a => a.service);
 
         this._networksManager.networks.forEach(network => {
+            if (this._favoritesOnly &&
+                !this._networksManager.getNetworkIsFavorite(network.id))
+                return;
+
             let sensitive = usedNetworks.indexOf(network.id) < 0;
             this._rows.set(network.id,
                            new ConnectionRow({ id: network.id,
@@ -173,6 +206,9 @@ var ConnectionsList = new Lang.Class({
         if (!this._networksManager.getAccountIsPredefined(account))
             return;
 
+        if (!this._rows.has(account.service))
+            return;
+
         this._rows.get(account.service).sensitive = sensitive;
     },
 
